<!DOCTYPE kpartgui>
<kpartgui name="KtikZ Viewer" version="4">
<MenuBar>
	<Menu name="file"><text context="@title:menu">&amp;File</text>
		<Action name="file_save_as"/>
		<Action name="file_export_as"/>
	</Menu>
	<Menu name="view"><text context="@title:menu">&amp;View</text>
		<Action name="view_zoom_in"/>
		<Action name="view_zoom_out"/>
		<Separator/>
		<Action name="view_previous_image"/>
		<Action name="view_next_image"/>
	</Menu>
	<Menu name="process"><text context="@title:menu">&amp;Process</text>
		<Action name="stop_process"/>
		<Action name="view_log"/>
		<Action name="shell_escape"/>
	</Menu>
	<Menu name="settings"><text context="@title:menu">&amp;Settings</text>
		<Action name="options_configure"/>
	</Menu>
	<Menu name="help"><text context="@title:menu">&amp;Help</text>
		<Action name="help_about_ktikz" group="about_merge"/>
	</Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text context="@title:menu toolbar title">Main Toolbar</text>
	<Action name="stop_process"/>
	<Action name="shell_escape"/>
	<Separator/>
	<Action name="view_zoom_in"/>
	<Action name="zoom_to"/>
	<Action name="view_zoom_out"/>
	<Separator/>
	<Action name="view_previous_image"/>
	<Action name="view_next_image"/>
</ToolBar>
</kpartgui>
