<?xml version='1.0' encoding='UTF-8'?>
<!DOCTYPE kpartgui SYSTEM 'kpartgui.dtd'>
<gui version="1" name="ktikz">
 <MenuBar>
  <Menu noMerge="1" name="file">
   <text context="@title:menu">&amp;File</text>
   <Action name="file_new"/>
   <DefineGroup name="new_merge"/>
   <Action name="file_open"/>
   <Action name="file_open_recent"/>
   <DefineGroup name="open_merge"/>
   <Separator/>
   <DefineGroup name="save_merge"/>
   <Action name="file_save"/>
   <Action name="file_save_as"/>
   <Separator/>
   <DefineGroup name="revert_merge"/>
   <Action name="file_reload"/>
   <Action name="file_reload_all"/>
   <Separator/>
   <DefineGroup name="print_merge"/>
   <Separator/>
   <Action name="file_print_preview"/>
   <Action name="file_print"/>
   <Action name="file_export_as"/>
<!--    <DefineGroup name="export_merge"/> -->
   <Separator/>
   <Action name="file_close"/>
   <DefineGroup name="close_merge"/>
   <Separator/>
   <Action name="file_quit"/>
  </Menu>
  <Menu noMerge="1" name="edit">
   <text context="@title:menu">&amp;Edit</text>
  </Menu>
  <Menu name="view">
    <text>&amp;View</text>
  </Menu>
  <Action name="insert"/>
  <Action name="user_insert"/>
  <Menu noMerge="1" name="process">
    <text context="@title:menu">&amp;Process</text>
    <Action name="build"/>
    <Action name="stop_process"/>
    <Action name="view_log"/>
    <Action name="shell_escape"/>
  </Menu>
  <Menu noMerge="1" name="preview">
    <text context="@title:menu">&amp;Preview</text>
    <Action name="view_zoom_in"/>
    <Action name="view_zoom_out"/>
    <Separator/>
    <Action name="view_previous_image"/>
    <Action name="view_next_image"/>
  </Menu>
  <Merge/>
  <Menu noMerge="1" name="settings">
   <text context="@title:menu">&amp;Settings</text>
   <Merge name="StandardToolBarMenuHandler"/>
   <Menu name="sidebars">
    <text context="@title:menu">&amp;Sidebars</text>
    <Action name="toggle_preview"/>
    <Action name="toggle_log"/>
    <Action name="toggle_commands_list"/>
   </Menu>
   <Action name="options_show_statusbar"/>
   <Separator/>
   <Action name="options_configure_keybinding"/>
   <Action name="options_configure_toolbars"/>
   <Action name="options_configure"/>
  </Menu>
  <Menu noMerge="1" name="help">
   <text context="@title:menu">&amp;Help</text>
   <Action name="help_contents"/>
   <Action name="show_tikz_doc"/>
   <Action name="help_whats_this"/>
   <Separator/>
   <Action name="help_report_bug"/>
   <Separator/>
   <Action name="switch_application_language"/>
   <Separator/>
   <Action name="help_about_editor"/>
   <Action name="help_about_app"/>
   <Action name="help_about_kde"/>
  </Menu>
 </MenuBar>
 <ToolBar noMerge="1" name="mainToolBar">
  <text context="@title:menu toolbar title">File Toolbar</text>
  <Action name="file_new"/>
  <Action name="file_open"/>
 <!-- <Action name="file_save"/>-->
  <Action name="file_close"/>
 </ToolBar>
<!-- <ToolBar noMerge="1" name="editToolBar">
  <text context="@title:menu toolbar title">Edit Toolbar</text>
  <Action name="edit_undo"/>
  <Action name="edit_redo"/>
 </ToolBar>-->
 <ToolBar noMerge="1" name="processToolBar">
  <text context="@title:menu toolbar title">Process Toolbar</text>
  <Action name="build"/>
  <Action name="stop_process"/>
  <Action name="view_log"/>
  <Action name="shell_escape"/>
 </ToolBar>
 <ToolBar noMerge="1" name="viewToolBar">
  <text context="@title:menu toolbar title">Preview Toolbar</text>
  <Action name="view_zoom_in"/>
  <Action name="zoom_to"/>
  <Action name="view_zoom_out"/>
  <Separator name="separator_0"/>
  <Action name="view_previous_image"/>
  <Action name="view_next_image"/>
 </ToolBar>
</gui>
